Learn R Programming

MeshesOperations (version 0.1.0)

tetrahedraCompound: Compound of five tetrahedra

Description

Five tetrahedra in a pretty configuration. Each tetrahedron is centered at the origin.

Usage

tetrahedraCompound

Arguments

Format

A list with three fields: the field meshes is a list of five elements, each one representing a tetrahedron by a list with two elements, the vertices and the faces; the field rglmeshes is the list of the five corresponding rgl meshes; the field gmpmeshes is the same as meshes except that the vertices are gmp rational numbers.