Learn R Programming

MeshesOperations (version 0.1.0)

truncatedIcosahedron: A mesh of the truncated icosahedron

Description

A list giving the vertices and the faces of a truncated icosahedron. There are some hexagonal faces and some pentagonal faces.

Usage

truncatedIcosahedron

Arguments

Format

A list with two fields: vertices and faces.