A list with three fields: the field meshes is a list of five
elements, each one representing a tetrahedron by a list with two elements,
the vertices and the faces; the field rglmeshes is the list of
the five corresponding rgl meshes; the field gmpmeshes is
the same as meshes except that the vertices are gmp
rational numbers.